#!/bin/ksh
#set -x
##################################################################################
#############
# File Name: changeTklmPassword.sh
#
#
# Licensed Materials - Property of IBM
#
# 5724-T60 5608-A91
# (C) Copyright IBM Corp. 2009  All Rights Reserved
#
# US Government Users Restricted Rights - Use, duplication, or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
#
##################################################################################
#############

printUsage() {

   echo "
   changeTklmPassword.sh [ TIP_USERNAME ] 
   changes Tivoli Key Lifecycle Manager tklmadmin's password,
   where
    -? Returns this command usage
    TIP_USERNAME is the Tivoli Integrated Portal user name 
    AIX, Solaris, Linux TIP location: /opt/IBM/tivoli/tip 
    To override the default TIP location, set the environment variable TIP_HOME prior to running. 
    Please make sure TKLM application is runing before executing this script.
    Example of the command with logging:
     changeTklmPassword.sh tipadmin | tee -a changeTklmPwd.log 2>&1
"
   exit 0
}

# stop was
stopWasServer() {
   echo "Stopping WAS server1"
   ${tipHome}/bin/stopServer.sh server1 -username $tipAdmin -password $tipAdminPwd
   rc=$?
   if [ $rc -ne 0 ]; then
      echo  "Exit Code=4, Error: Failed to stop WAS server1, the error code from stopServer is $rc"
      exit 4
   fi
}

# start was
startWasServer() {
   echo "Starting WAS server1"
   ${tipHome}/bin/startServer.sh server1 > /dev/null 2>&1
   rc=$?
   if [ $rc -ne 0 ] ; then
      echo "Exit Code=5, Error: Failed to start WAS server1, the error code from startServer is $rc"
      exit 5
   fi
}


trap 'stty echo; exit' 0 1 2 3 15

if [ $# -lt 1 ] || [ "$*" = "-?" ]; then
     printUsage
fi

program=`echo $0 | sed -e 's%\\\\%/%g'`
username=`id | awk '$1 == "uid=0(root)" {printf("root")}'`
if [ "$username" != "root" ]
then
  echo "Exit Code=-1. Error: You must be running as root in order to run the program."
  exit -1
fi

#
# get the tipAdmin's password
#
tipAdmin="$1"
echo "Enter $tipAdmin's password:"
   stty -echo
   read pwd1
   echo "Reenter the password:"
   read pwd2
   stty echo

   if [ ! -n "$pwd2" ] || [ ! -n "$pwd1" ] ; then
     echo "Exit Code=6. Error: The password can not be empty."
     exit 6
   fi

   if [ $pwd1 != $pwd2 ]; then
     echo "Exit Code=1. Error: The passwords do not match."
     exit 1
   fi

tipAdminPwd=$pwd1

#
# get the tklmAdmin's new passsword
#
tklmAdmin="tklmAdmin"
   echo " "
   echo "Enter $tklmAdmin's new password:"
   stty -echo
   read pwd1
   checkStr=`echo $pwd1 | awk '{print $2}'`
   if [ -n "${checkStr}" ]; then
      echo "Exit Code=7. Error: The password contains space, try again."
      exit 7
   fi

   echo "Reenter the new password:"
   read pwd2
   stty echo
   if [ ! -n "$pwd2" ] || [ ! -n "$pwd1" ] ; then
     echo "Exit Code=6. Error: The password can not be empty."
     exit 6
   fi

   if [ $pwd1 != $pwd2 ]; then
     echo "Exit Code=1. Error: The passwords do not match."
     exit 1
   fi

tklmAdminNewPwd=$pwd1
# for debugging
#echo tipAdmin=$tipAdmin tipAdminPwd=$tipAdminPwd tklmAdmin=$tklmAdmin tklmAdminNewPwd=$tklmAdminNewPwd

tipHome=${TIP_HOME}
if [ -z "${TIP_HOME}" ] || [ ! -d ${TIP_HOME} ]; then
    tipHome=/opt/IBM/tivoli/tip
    if [ ! -d ${tipHome} ]; then
       echo "Enter TIP_HOME path(if you have multiple TIP installation, make sure to enter the correct one:"
       read tipHome
       if [ ! -d ${tipHome} ]; then
          echo "TIP_HOME: ${tipHome} does not exist"
          echo Exit Code=3. Error: found problem with TIP_HOME.
          exit 3
       fi
    fi
fi


registryFilePath=${tipHome}/profiles/TIPProfile/config/cells/TIPCell
registryFile=fileRegistry.xml 
tipTemp=${tipHome}/temp
if [ ! -f ${registryFilePath}/${registryFile} ]; then
  echo "Exit Code=8. Error: TIP Registry file is missing,it could be bad TIP_HOME."
  exit 8
fi

echo "Back up the registry file: ${registryFilePath}/${registryFile} to ${tipTemp} ..."
cp -f ${registryFilePath}/${registryFile}  ${tipTemp}/${registryFile}

echo "Running wsadmin to change tklmadmin's password ..."
wsadminCmd=${tipHome}/bin/wsadmin.sh
options="-username $tipAdmin -password ${tipAdminPwd} -profileName TIPProfile -lang jython"
${wsadminCmd} ${options} -c "AdminTask.changeFileRegistryAccountPassword ('-userId tklmadmin -password ${tklmAdminNewPwd}')" "AdminConfig.save()" >/dev/null 2>&1
rc=$?
if [ $rc -ne 0 ]; then
    echo  "Exit Code=2. Error: Failed to change tklmadmin's password, the error code from wsadmin is $rc."
    exit 2
fi	

#stop WAS server1
echo "Restart the WebSphere server1, this may take several minutes ..."
stopWasServer

# start WAS server1
startWasServer

echo "tklmadmin's password have been successfully changed."
exit 0
